@@ -2,7 +2,7 @@
 #define FLINT_USES_TLS 1
 
 /* Define if the library should be thread-safe, no matter whether FLINT_USES_TLS is used */
-#define FLINT_REENTRANT 1
+#define FLINT_REENTRANT 0
 
 /* Define if -DCMAKE_BUILD_TYPE=Debug was given, to enable some ASSERT()s */
 #define FLINT_WANT_ASSERT 0
@@ -12,26 +12,21 @@
 
 #define FLINT_USES_PTHREAD 1
 
-#define FLINT_USES_POPCNT
-
 #define FLINT_USES_BLAS 1
 
 #define FLINT_USES_FENV 1
 
-#ifdef _MSC_VER
-#define access _access
-#define strcasecmp _stricmp
-#define strncasecmp	_strnicmp
-#define alloca _alloca
-#define MSC_C_(x) #x  
-#define MSC_CC_(x)  MSC_C_(x)
-#define MSC_VERSION "Microsoft C++ (Version " MSC_CC_(_MSC_FULL_VER) ")"
-#endif
+#define FLINT_HAVE_FFT_SMALL
 
-#if defined (FLINT_BUILD_DLL)
-#define FLINT_DLL __declspec(dllexport)
-#elif defined(MSC_USE_DLL)
-#define FLINT_DLL __declspec(dllimport)
-#else
-#define FLINT_DLL
+#define FLINT_KNOW_STRONG_ORDER 0
+
+/* Just set to some reasonable threshold */
+#define FLINT_FFT_SMALL_THRESHOLD 600
+
+#ifdef _MSC_VER
+# if defined(FLINT_BUILD_DLL)
+#  define FLINT_DLL __declspec(dllexport)
+# else
+#  define FLINT_DLL __declspec(dllimport)
+# endif
 #endif
